@@ -12,9 +12,10 @@
 
 terms.inner <- function (x) 
 {
-  if (class(x) == "formula") 
-    c(terms.inner(x[[2]]), terms.inner(x[[3]]))
-  else if (class(x) == "call" && (x[[1]] != as.name("$") && 
+  #if (class(x) == "formula") 
+  #  c(terms.inner(x[[2]]), terms.inner(x[[3]]))
+  #else 
+  if (class(x) == "call" && (x[[1]] != as.name("$") && 
                                   x[[1]] != as.name("["))) {
     if (x[[1]] == "+" || x[[1]] == "*" || x[[1]] == "-") {
       c(terms.inner(x[[2]]), terms.inner(x[[3]]))
